Package: visOmopResults
Title: Graphs and Tables for OMOP Results
Version: 1.5.0
Authors@R: c(
    person(
      "Martí", "Català", , "marti.catalasabate@ndorms.ox.ac.uk", 
      role = c("aut"), comment = c(ORCID = "0000-0003-3308-9905")
    ),
    person(
      "Núria", "Mercadé-Besora", , "nuria.mercadebesora@ndorms.ox.ac.uk", 
      role = c("aut", "cre"), comment = c(ORCID = "0009-0006-7948-3747")
    ),
    person(
      "Yuchen", "Guo", , "yuchen.guo@ndorms.ox.ac.uk", 
      role = c("ctb"), comment = c(ORCID = "0000-0002-0847-4855")
    ),
    person(
      "Elin", "Rowlands", , "elin.rowlands@ndorms.ox.ac.uk", 
      role = c("ctb"), comment = c(ORCID = "0009-0007-6629-4661")
    ),
    person(
      "Marta", "Alcalde-Herraiz", , "marta.alcaldeherraiz@ndorms.ox.ac.uk", 
      role = c("ctb"), comment = c(ORCID = "0009-0002-4405-1814")
    ),
    person(
      "Edward", "Burn", , "edward.burn@ndorms.ox.ac.uk", 
      role = c("ctb"), comment = c(ORCID = "0000-0002-9286-1128")
    )
  )
Maintainer: Núria Mercadé-Besora <nuria.mercadebesora@ndorms.ox.ac.uk>
Description: Provides methods to transform omop_result objects into
    formatted tables and figures, facilitating the visualisation of study
    results working with the Observational Medical Outcomes Partnership
    (OMOP) Common Data Model.
License: Apache License (>= 2)
URL: https://darwin-eu.github.io/visOmopResults/,
        https://github.com/darwin-eu/visOmopResults
BugReports: https://github.com/darwin-eu/visOmopResults/issues
Imports: brand.yml, cli, dplyr, generics, glue, omopgenerics (>=
        0.3.1), purrr, rlang, stringr, systemfonts, tidyr
Suggests: bslib, CohortCharacteristics, covr, DT, flextable (>= 0.9.5),
        ggalluvial, ggplot2, ggsankeyfier, gt, here, htmltools,
        IncidencePrevalence, knitr, lifecycle, officer, palmerpenguins,
        PatientProfiles, plotly, reactable, rmarkdown, shiny,
        shinycssloaders, shinyWidgets, sortable, testthat (>= 3.0.0),
        tinytable (>= 0.14.0), yaml
VignetteBuilder: knitr
Depends: R (>= 4.1)
Config/testthat/edition: 3
Config/testthat/parallel: true
Encoding: UTF-8
LazyData: true
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-17 20:25:43 UTC; nuriamb
Author: Martí Català [aut] (ORCID: <https://orcid.org/0000-0003-3308-9905>),
  Núria Mercadé-Besora [aut, cre] (ORCID:
    <https://orcid.org/0009-0006-7948-3747>),
  Yuchen Guo [ctb] (ORCID: <https://orcid.org/0000-0002-0847-4855>),
  Elin Rowlands [ctb] (ORCID: <https://orcid.org/0009-0007-6629-4661>),
  Marta Alcalde-Herraiz [ctb] (ORCID:
    <https://orcid.org/0009-0002-4405-1814>),
  Edward Burn [ctb] (ORCID: <https://orcid.org/0000-0002-9286-1128>)
Repository: CRAN
Date/Publication: 2026-05-18 05:20:02 UTC
Built: R 4.6.0; ; 2026-05-18 05:32:22 UTC; unix
