# Generated by roxygen2: do not edit by hand

export(addSettings)
export(additionalColumns)
export(alluvialPlot)
export(barPlot)
export(bind)
export(boxPlot)
export(customiseText)
export(emptyPlot)
export(emptyTable)
export(exportSummarisedResult)
export(filterAdditional)
export(filterGroup)
export(filterSettings)
export(filterStrata)
export(formatEstimateName)
export(formatEstimateValue)
export(formatHeader)
export(formatMinCellCount)
export(formatTable)
export(groupColumns)
export(importSummarisedResult)
export(mockSummarisedResult)
export(pivotEstimates)
export(plotColumns)
export(plotStyle)
export(plotType)
export(scatterPlot)
export(setGlobalPlotOptions)
export(setGlobalTableOptions)
export(settings)
export(settingsColumns)
export(splitAdditional)
export(splitAll)
export(splitGroup)
export(splitStrata)
export(strataColumns)
export(suppress)
export(tableColumns)
export(tableOptions)
export(tableStyle)
export(tableType)
export(themeVisOmop)
export(tidy)
export(tidyColumns)
export(uniteAdditional)
export(uniteGroup)
export(uniteStrata)
export(visOmopTable)
export(visTable)
importFrom(generics,tidy)
importFrom(omopgenerics,addSettings)
importFrom(omopgenerics,additionalColumns)
importFrom(omopgenerics,bind)
importFrom(omopgenerics,exportSummarisedResult)
importFrom(omopgenerics,filterAdditional)
importFrom(omopgenerics,filterGroup)
importFrom(omopgenerics,filterSettings)
importFrom(omopgenerics,filterStrata)
importFrom(omopgenerics,groupColumns)
importFrom(omopgenerics,importSummarisedResult)
importFrom(omopgenerics,pivotEstimates)
importFrom(omopgenerics,settings)
importFrom(omopgenerics,settingsColumns)
importFrom(omopgenerics,splitAdditional)
importFrom(omopgenerics,splitAll)
importFrom(omopgenerics,splitGroup)
importFrom(omopgenerics,splitStrata)
importFrom(omopgenerics,strataColumns)
importFrom(omopgenerics,suppress)
importFrom(omopgenerics,tidy)
importFrom(omopgenerics,tidyColumns)
importFrom(omopgenerics,uniteAdditional)
importFrom(omopgenerics,uniteGroup)
importFrom(omopgenerics,uniteStrata)
importFrom(rlang,"%||%")
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlang,.env)
